/******************************************************************************
 * FILE: HoneywellAltimeter.c
 *
 * DESCRIPTION:
 * This is an Object Oriented C class header that is able to read the data of 
 * ASDX*030*A24R*DO Honeywell absolute pressure sensor.
 *
 * CREATED: 07-07-10: Kyle Dobitz
 * University of Minnesota 
 * Aerospace Engineering and Mechanics 
 *  2011 Regents of the University of Minnesota. All rights reserved.
 *
 * $Id: HoneywellAltimeter.h 253 2011-01-20 22:01:35Z murch $
 ******************************************************************************/



typedef struct honeywellaltimeter * HoneywellAltimeter;

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// Public methods
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// samples the instantaneous differential pressure
cyg_uint32 HoneywellAltimeter_readPressure(HoneywellAltimeter);

// Removed: returns the sampled differential pressure from +1 psi to -1 psi and altitude in meters
// New: returns the sampled differential pressure from 6.89475729 KPa to -1 6.89475729 KPa and altitude in meters
double HoneywellAltimeter_getPressure(HoneywellAltimeter);

double HoneywellAltimeter_getAltitude(HoneywellAltimeter);

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// Constructor takes as input the i2c interface device, and the minimum and maximum pressure
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
HoneywellAltimeter new_HoneywellAltimeter(cyg_i2c_device *, double, double);

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// Destructor
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
void delete_HoneywellAltimeter(HoneywellAltimeter);
